<p align="center">
    <img alt="logo" src="https://samp-mobile.com/style/img/logo.png">
</p>

<h1 align="center">Программа для подбора паролей SAMP Mobile</h1>

<p align="center">
    <img alt="Made with Python" src="https://img.shields.io/badge/Made%20with-Python-%23FFD242?logo=python&logoColor=white">
    <img alt="License" src="https://img.shields.io/github/license/UHl0aG9uZWVy/SA-MP-Mobile-Bruteforce?style=flat-square)">
</p>

> Разработчик не несет ответсвенности за неправомерное использование данной программы

## Установка и использование
1. Установка Python:
    #### Windows
    Скачать Python можно с официального [сайта](https://python.org/downloads), при установке необходимо поставить галочку Add Python to PATH

    #### Linux
    ```sh
    apt install python3
    apt install python3-pip
    ```

    #### Android (экспериментально)
    Необходимо установить [Termux](https://play.google.com/store/apps/details?id=com.termux), для ввода в него следующей команды
    ```sh
    pkg install python
    ```

2. Установка sabrute:
    ```sh
    pip3 install sabrute
    ```

3. Использование:
    ```sh
    sabrute --nickname [nickname]
    ```

## Автор
- [VK](https://vk.com/vegvs)
- [TG](https://t.me/pycharmgovno)
